@@ -19,11 +19,19 @@ class DirectoryExistError(RuntimeError):
     def __init__(self, arg):
         self.args = arg
 
+# an runtime error
+# file type is unknown
+class FileTypeUnknownError(RuntimeError):
+    def __init__(self, arg):
+        self.args = arg
+
 class inputGenerator():
-    ''' generate all the inputs and define corresponding slots '''
+    """generate all the inputs and define corresponding slots
+    """
 
     def __init__(self):
-        ''' simply initialize the configTemplate objects '''
+        """simply initialize the configTemplate objects
+        """
 
         self.cTemplate = configTemplate.configTemplate()
 
@@ -41,23 +49,31 @@ class inputGenerator():
         doubleWide = False,
         minBeforeSample = False,
         membraneProtein = False,
+        pinDownPro = True,
         vmdPath = ''
     ):
-        ''' generate all the input files for NAMD alchemical simulation
-            Inputs:
-                path (string): the directory for generation of all the files
-                topFile (string): the path of the topology (psf, parm) file
-                coorFile (string): the path of the coordinate (pdb, rst7) file
-                forceFieldType (string): 'charmm' or 'amber'
-                forceFieldFiles (list of strings): list of CHARMM force field files
-                temperature (float): temperature of the simulation
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                stratification (list of int, 8): number of windows for each simulation
-                doubleWide (bool): whether double-wide simulations are carried out
-                minBeforeSample (bool): minimization before sampling in each FEP window
-                membraneProtein (bool): whether simulating a membrane protein
-                vmdPath (string): path to vmd '''
+        """generate all the input files for NAMD alchemical simulation
+
+        Args:
+            path (str): the directory for generation of all the files
+            topFile (str): the path of the topology (psf, parm) file
+            coorFile (str): the path of the coordinate (pdb, rst7) file
+            forceFieldType (str): 'charmm' or 'amber'
+            forceFieldFiles (list of str): list of CHARMM force field files
+            temperature (float): temperature of the simulation
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            stratification (list of int, 8, optional): number of windows for each simulation.
+                                                       Defaults to [1,1,1,1].
+            doubleWide (bool, optional): whether double-wide simulations are carried out. 
+                                         Defaults to False.
+            minBeforeSample (bool, optional): minimization before sampling in each FEP window.
+                                              Defaults to False.
+            membraneProtein (bool, optional): whether simulating a membrane protein.
+                                              Defaults to False.
+            pinDownPro (bool, optional): whether pinning down the protien. Defaults to True.
+            vmdPath (str, optional): path to vmd. Defaults to ''.
+        """
 
         assert(len(stratification) == 4)
         assert(forceFieldType == 'charmm' or forceFieldType == 'amber')
@@ -84,7 +100,7 @@ class inputGenerator():
             membraneProtein
         )
         self._generateAlchemicalColvarsConfig(
-            path, topType, 'pdb', selectionPro, selectionLig, selectionPro, stratification
+            path, topType, 'pdb', selectionPro, selectionLig, selectionPro, stratification, pinDownPro
         )
 
     def generateNAMDGeometricFiles(
@@ -102,27 +118,35 @@ class inputGenerator():
         userProvidedPullingCoor = '',
         stratification = [1,1,1,1,1,1,1,1],
         membraneProtein = False,
+        pinDownPro = True,
         parallelRuns = 1,
         vmdPath = ''
     ):
-        ''' generate all the input files for NAMD Geometric simulation
-            Inputs:
-                path (string): the directory for generation of all the files
-                topFile (string): the path of the topology (psf, parm) file
-                coorFile (string): the path of the coordinate (pdb, rst7) file
-                forceFieldType (string): 'charmm' or 'amber'
-                forceFieldFiles (list of strings): list of CHARMM force field files
-                temperature (float): temperature of the simulation
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                selectionRef (string): MDAnalysis-style selection of the reference group for pulling simulation,
-                                       by default, this is the protein
-                userProvidedPullingTop (string): user-provided large solvation box for pulling simulation
-                userProvidedPullingCoor (string): user-provided large solvation box for pulling simulation
-                stratification (list of int, 8): number of windows for each simulation
-                membraneProtein (bool): whether simulation a membrane protein
-                parallelRuns (int): generate files for duplicate runs
-                vmdPath (string): path to vmd '''
+        """generate all the input files for NAMD geometric simulation
+
+        Args:
+            path (str): the directory for generation of all the files
+            topFile (str): the path of the topology (psf, parm) file
+            coorFile (str): the path of the coordinate (pdb, rst7) file
+            forceFieldType (str): 'charmm' or 'amber'
+            forceFieldFiles (list of str): list of CHARMM force field files
+            temperature (float): temperature of the simulation
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            selectionRef (str, optional): MDAnalysis-style selection of the reference group for pulling simulation,
+                                          by default, this is the protein. 
+                                          Defaults to ''.
+            userProvidedPullingTop (str, optional): user-provided large solvation box for pulling simulation.
+                                                    Defaults to ''.
+            userProvidedPullingCoor (str, optional): user-provided large solvation box for pulling simulation. 
+                                                     Defaults to ''.
+            stratification (list, optional): number of windows for each simulation. 
+                                             Defaults to [1,1,1,1,1,1,1,1].
+            membraneProtein (bool, optional): whether simulation a membrane protein. Defaults to False.
+            pinDownPro (bool, optional): whether pinning down the protien. Defaults to True.
+            parallelRuns (int, optional): generate files for duplicate runs. Defaults to 1.
+            vmdPath (str, optional): path to vmd. Defaults to ''.
+        """ 
 
         assert(len(stratification) == 8)
         assert(forceFieldType == 'charmm' or forceFieldType == 'amber')
@@ -150,7 +174,7 @@ class inputGenerator():
             path, forceFieldType, relativeFFPath, temperature, stratification, membraneProtein
         )
         self._generateGeometricColvarsConfig(
-            path, topType, coorType, selectionPro, selectionLig, selectionRef, stratification
+            path, topType, coorType, selectionPro, selectionLig, selectionRef, stratification, pinDownPro
         )
 
         self._duplicateFileFolder(path, parallelRuns)
@@ -167,18 +191,24 @@ class inputGenerator():
         selectionSol='resname TIP3* or resname SPC*',
         temperature=300.0
     ):
-        ''' generate all the input files for Gromacs Geometric simulation
-            This function is based on BFEEGromacs.py
-            contributed by Haochuan Chen (yjcoshc_at_mail.nankai.edu.cn)
-            Inputs:
-                path (string): the directory for generation of all the files
-                topFile (string): the path of the topology (top) file
-                pdbFile (string): the path of the coordinate (pdb) file
-                ligandOnlyTopFile (string): the path of the ligand-only topology (top) file
-                ligandOnlyPdbFile (string): the path of the ligand-only coordinate (pdb) file
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                selectionSol (string): MDAnalysis-style selection of the solvent '''
+        """generate all the input files for Gromacs Geometric simulation
+           This function is based on BFEEGromacs.py
+           contributed by Haochuan Chen (yjcoshc_at_mail.nankai.edu.cn)
+        Args:
+            path (str): the directory for generation of all the files
+            topFile (str): the path of the topology (top) file
+            pdbFile (str): the path of the coordinate (pdb) file
+            ligandOnlyTopFile (str): the path of the ligand-only topology (top) file
+            ligandOnlyPdbFile (str): the path of the ligand-only coordinate (pdb) file
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            selectionSol (str, optional): MDAnalysis-style selection of the solvent. 
+                                          Defaults to 'resname TIP3* or resname SPC*'.
+            temperature (float, optional): Temperature of the simulation. Defaults to 300.0.
+
+        Raises:
+            DirectoryExistError: when {path}/BFEE exists
+        """        
         
         # if the folder already exists, raise an error
         if os.path.exists(f'{path}/BFEE'):
@@ -212,12 +242,21 @@ class inputGenerator():
 
 
     def _determineFileType(self, topFile, coorFile):
-        ''' determine the file type of topology and coordinate files
-            Inputs:
-                topFile (string): the path of the topology (psf, parm) file
-                coorFile (string): the path of the coordinate (pdb, rst7) file
-            Return:
-                tuple of string, 2: (topType, coorType), e.g., (psf, pdb) '''
+        """determine the file type of topology and coordinate files
+
+        Args:
+            topFile (str): the path of the topology (psf, parm) file
+            coorFile (str): the path of the coordinate (pdb, rst7) file
+
+        Raises:
+            FileTypeUnknownError: if the postfix of topFile is not 
+                                  psf, parm, prm7, parm7, prmtop
+                                  or the postfix of coorFile is not
+                                  pdb, coor, rst7, rst, inpcrd
+
+        Returns:
+            tuple of str: (topType, coorType), e.g., (psf, pdb)
+        """
 
         topPostfix = os.path.splitext(topFile)[-1]
         coorPostfix = os.path.splitext(coorFile)[-1]
@@ -232,18 +271,26 @@ class inputGenerator():
 
         if coorPostfix == '.pdb':
             coorType = 'pdb'
+        elif coorPostfix == '.coor':
+            coorType = 'namdbin'
         elif coorPostfix == '.rst7' or coorPostfix == '.rst' or coorPostfix == '.inpcrd':
             coorType = 'inpcrd'
 
-        assert(topType != '' and coorType != '')
+        if topType == '' or coorType == '':
+            raise FileTypeUnknownError('File type unknown')
 
         return topType, coorType
 
     def _makeDirectories(self, path, jobType='geometric'):
-        ''' make directories for BFEE calculation
-            Inputs:
-                path (string): the path for putting BFEE input files into
-                jobType (string): geometric or alchemical '''
+        """make directories for BFEE calculation
+
+        Args:
+            path (str): the path for putting BFEE input files into
+            jobType (str, optional): geometric or alchemical. Defaults to 'geometric'.
+
+        Raises:
+            DirectoryExistError: if {path}/BFEE exists
+        """        
 
         # if the folder already exists, raise an error
         if os.path.exists(f'{path}/BFEE'):
@@ -298,23 +345,27 @@ class inputGenerator():
         membraneProtein = False,
         vmdPath = ''
     ):
-        ''' copy original and generate necessary topology/structure files
-            Inputs:
-                path (string): the directory for generation of all the files
-                topFile (string): the path of the topology (psf, parm) file
-                topType (string): the type (psf, parm) of the topology file
-                coorFile (string): the path of the coordinate (pdb, rst7) file
-                coorType (string): the type (pdb, rst) of the coordinate file
-                forceFieldType (string): 'charmm' or 'amber'
-                forceFieldFiles (list of strings): list of CHARMM force field files
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                selectionRef (string): MDAnalysis-style selection of the reference group for pulling simulation
-                userProvidedPullingTop (string): user-provided large solvation box for pulling simulation
-                userProvidedPullingCoor (string): user-provided large solvation box for pulling simulation
-                jobType (string): 'geometric' or 'alchemical'
-                membraneProtein (bool): whether simulating a membrane protein
-                vmdPath (string): path to vmd, space is forbidden '''
+        """copy original and generate necessary topology/structure files
+
+        Args:
+            path (str): the directory for generation of all the files
+            topFile (str): the path of the topology (psf, parm) file
+            topType (str): the type (psf, parm) of the topology file
+            coorFile (str): the path of the coordinate (pdb, rst7) file
+            coorType (str): the type (pdb, rst) of the coordinate file
+            forceFieldType (str): 'charmm' or 'amber'
+            forceFieldFiles (list of str): list of CHARMM force field files
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            selectionRef (str): MDAnalysis-style selection of the reference group for pulling simulation
+            userProvidedPullingTop (str, optional): user-provided large solvation box for pulling simulation. 
+                                                    Defaults to ''.
+            userProvidedPullingCoor (str, optional): user-provided large solvation box for pulling simulation. 
+                                                     Defaults to ''.
+            jobType (str, optional): 'geometric' or 'alchemical'. Defaults to 'geometric'.
+            membraneProtein (bool, optional): whether simulating a membrane protein. Defaults to False.
+            vmdPath (str, optional): path to vmd, space is forbidden. Defaults to ''.
+        """
         
         # copy force fields
         if forceFieldType == 'charmm':
@@ -535,16 +586,22 @@ class inputGenerator():
         minBeforeSample = False,
         membraneProtein = False
     ):
-        ''' generate NAMD config fils for the alchemical route
-            Inputs:
-                path (string): the directory for generation of all the files
-                forceFieldType (string): 'charmm' or 'amber'
-                forceFieldFiles (list of strings): list of CHARMM force field files
-                temperature (float): temperature of the simulation
-                stratification (list of int, 4): number of windows for each simulation
-                doubleWide (bool): whether double-wide simulations are carried out
-                minBeforeSample (bool): minimization before sampling in each FEP window
-                membraneProtein (bool): whether simulating a membrane protein  '''
+        """generate NAMD config fils for the alchemical route
+
+        Args:
+            path (str): the directory for generation of all the files
+            forceFieldType (str): 'charmm' or 'amber'
+            forceFields (list of str): list of CHARMM force field files
+            temperature (float): temperature of the simulation
+            stratification (list of int, 4, optional): number of windows for each simulation. 
+                                                       Defaults to [1,1,1,1].
+            doubleWide (bool, optional): whether double-wide simulations are carried out. 
+                                         Defaults to False.
+            minBeforeSample (bool, optional): minimization before sampling in each FEP window. 
+                                              Defaults to False.
+            membraneProtein (bool, optional): whether simulating a membrane protein. 
+                                              Defaults to False.
+        """
 
         if forceFieldType == 'charmm':
             topType = 'psf'
@@ -693,17 +750,21 @@ class inputGenerator():
             )
 
     def _generateAlchemicalColvarsConfig(
-        self, path, topType, coorType, selectionPro, selectionLig, selectionRef, stratification=[1,1,1,1]
+        self, path, topType, coorType, selectionPro, selectionLig, selectionRef, stratification=[1,1,1,1], pinDownPro=True
     ):
-        ''' generate Colvars config fils for geometric route
-            Inputs:
-                path (string): the directory for generation of all the files
-                topType (string): the type (psf, parm) of the topology file
-                coorType (string): the type (pdb, rst) of the topology file
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                selectionRef (string): MDAnalysis-style selection of the reference group for pulling simulation
-                stratification (list of int, 4): number of windows for each simulation ''' 
+        """generate Colvars config fils for geometric route
+
+        Args:
+            path (str): the directory for generation of all the files
+            topType (str): the type (psf, parm) of the topology file
+            coorType (str): the type (pdb, rst) of the topology file
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            selectionRef (str): MDAnalysis-style selection of the reference group for pulling simulation
+            stratification (list of int, 4, optional): number of windows for each simulation. 
+                                                       Defaults to [1,1,1,1].
+            pinDownPro (bool, optinal): Whether pinning down the protein. Defaults to True.
+        """
 
         assert(len(stratification) == 4)
 
@@ -846,9 +907,10 @@ class inputGenerator():
             colvarsConfig.write(
                 self.cTemplate.cvHarmonicTemplate('r', 10, distance)
             )
-            colvarsConfig.write(
-                self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-            )
+            if pinDownPro:
+                colvarsConfig.write(
+                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                )
 
         # 002_RestraintBound
         with open(f'{path}/BFEE/002_RestraintBound/colvars_forward.in', 'w') as colvarsConfig:
@@ -909,9 +971,10 @@ class inputGenerator():
             colvarsConfig.write(
                 self.cTemplate.cvHarmonicTemplate('r', 0, distance, stratification[1], True, 10)
             )
-            colvarsConfig.write(
-                self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-            )
+            if pinDownPro:
+                colvarsConfig.write(
+                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                )
         with open(f'{path}/BFEE/002_RestraintBound/colvars_backward.in', 'w') as colvarsConfig:
             colvarsConfig.write(
                 self.cTemplate.cvHeadTemplate('../complex.ndx')
@@ -970,9 +1033,10 @@ class inputGenerator():
             colvarsConfig.write(
                 self.cTemplate.cvHarmonicTemplate('r', 0, distance, stratification[1], False, 10)
             )
-            colvarsConfig.write(
-                self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-            )
+            if pinDownPro:
+                colvarsConfig.write(
+                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                )
 
         # 003_MoleculeUnbound
         with open(f'{path}/BFEE/003_MoleculeUnbound/colvars.in', 'w') as colvarsConfig:
@@ -1017,14 +1081,17 @@ class inputGenerator():
         stratification = [1,1,1,1,1,1,1,1],
         membraneProtein = False,
     ):
-        ''' generate NAMD config fils for the geometric route
-            Inputs:
-                path (string): the directory for generation of all the files
-                forceFieldType (string): 'charmm' or 'amber'
-                forceFieldFiles (list of strings): list of CHARMM force field files
-                temperature (float): temperature of the simulation
-                stratification (list of int, 8): number of windows for each simulation
-                membraneProtein (bool): whether simulating a membrane protein  '''
+        """generate NAMD config fils for the geometric route
+
+        Args:
+            path (str): the directory for generation of all the files
+            forceFieldType (str): 'charmm' or 'amber'
+            forceFieldFiles (list of str): list of CHARMM force field files
+            temperature (float): temperature of the simulation
+            stratification (list of int, 8): number of windows for each simulation. 
+                                             Defaults to [1,1,1,1,1,1,1,1].
+            membraneProtein (bool, optional): whether simulating a membrane protein. Defaults to False.
+        """
 
         if forceFieldType == 'charmm':
             topType = 'psf'
@@ -1351,7 +1418,7 @@ class inputGenerator():
                 self.cTemplate.namdConfigTemplate(
                     forceFieldType, forceFields, f'./complex_largeBox.{topType}', f'./complex_largeBox.pdb',
                     'output/eq.coor', 'output/eq.vel', 'output/eq.xsc', '',
-                    'output/abf_1', temperature, 5000000, 'colvars_1.in', '',
+                    'output/abf_1', temperature, 20000000, 'colvars_1.in', '',
                     membraneProtein=membraneProtein
                 )
             )
@@ -1360,7 +1427,7 @@ class inputGenerator():
                 self.cTemplate.namdConfigTemplate(
                     forceFieldType, forceFields, f'./complex_largeBox.{topType}', f'./complex_largeBox.pdb',
                     'output/abf_1.coor', 'output/abf_1.vel', 'output/abf_1.xsc', '',
-                    'output/abf_1.extend', temperature, 5000000, 'colvars_1.in', '',
+                    'output/abf_1.extend', temperature, 20000000, 'colvars_1.in', '',
                     CVRestartFile=f'output/abf_1', membraneProtein=membraneProtein
                 )
             )
@@ -1374,7 +1441,7 @@ class inputGenerator():
                         forceFieldType, forceFields, f'./complex_largeBox.{topType}', f'./complex_largeBox.pdb',
                         f'output/abf_{i}.coor', f'output/abf_{i}.vel', 
                         f'output/abf_{i}.xsc',
-                        '', f'output/abf_{i+1}', temperature, 5000000, f'colvars_{i+1}.in', '',
+                        '', f'output/abf_{i+1}', temperature, 20000000, f'colvars_{i+1}.in', '',
                         membraneProtein=membraneProtein
                     )
                 )
@@ -1384,7 +1451,7 @@ class inputGenerator():
                         forceFieldType, forceFields, f'./complex_largeBox.{topType}', f'./complex_largeBox.pdb',
                         f'output/abf_{i+1}.coor', f'output/abf_{i+1}.vel', 
                         f'output/abf_{i+1}.xsc',
-                        '', f'output/abf_{i+1}.extend', temperature, 5000000, f'colvars_{i+1}.in', '',
+                        '', f'output/abf_{i+1}.extend', temperature, 20000000, f'colvars_{i+1}.in', '',
                         CVRestartFile=f'output/abf_{i+1}', membraneProtein=membraneProtein
                     )
                 )
@@ -1443,17 +1510,29 @@ class inputGenerator():
                 )
 
     def _generateGeometricColvarsConfig(
-        self, path, topType, coorType, selectionPro, selectionLig, selectionRef, stratification=[1,1,1,1,1,1,1,1]
+        self, 
+        path, 
+        topType, 
+        coorType, 
+        selectionPro, 
+        selectionLig, 
+        selectionRef, 
+        stratification=[1,1,1,1,1,1,1,1], 
+        pinDownPro=True
     ):
-        ''' generate Colvars config fils for geometric route
-            Inputs:
-                path (string): the directory for generation of all the files
-                topType (string): the type (psf, parm) of the topology file
-                coorType (string): the type (pdb, rst) of the topology file
-                selectionPro (string): MDAnalysis-style selection of the protein
-                selectionLig (string): MDAnalysis-style selection of the ligand
-                selectionRef (string): MDAnalysis-style selection of the reference group for pulling simulation
-                stratification (list of int, 8): number of windows for each simulation ''' 
+        """generate Colvars config fils for geometric route
+
+        Args:
+            path (str): the directory for generation of all the files
+            topType (str): the type (psf, parm) of the topology file
+            coorType (str): the type (pdb, rst) of the topology file
+            selectionPro (str): MDAnalysis-style selection of the protein
+            selectionLig (str): MDAnalysis-style selection of the ligand
+            selectionRef (str): MDAnalysis-style selection of the reference group for pulling simulation
+            stratification (list of int, 8, optional): number of windows for each simulation. 
+                                                       Defaults to [1,1,1,1,1,1,1,1].
+            pinDownPro (bool, optional): Whether pinning down the protein. Defaults to True.
+        """    
 
         assert(len(stratification) == 8)
 
@@ -1491,9 +1570,10 @@ class inputGenerator():
                         'RMSD', float(i)/stratification[0] * 3.0, float(i+1)/stratification[0] * 3.0
                     )
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 002_Theta
         for i in range(stratification[1]):
@@ -1520,9 +1600,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('RMSD', 10, 0)
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 003_Phi
         for i in range(stratification[2]):
@@ -1557,9 +1638,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('eulerTheta', 0.1, 0)
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 004_Psi
         for i in range(stratification[3]):
@@ -1602,9 +1684,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('eulerPhi', 0.1, 0)
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 005_polarTheta
         for i in range(stratification[4]):
@@ -1657,9 +1740,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('eulerPsi', 0.1, 0)
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 006_polarPhi
         for i in range(stratification[5]):
@@ -1720,9 +1804,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('polarTheta', 0.1, polarAngles[0])
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, '../complex.xyz')
+                    )
 
         # 007_r
         # eq
@@ -1847,9 +1932,10 @@ class inputGenerator():
                 colvarsConfig.write(
                     self.cTemplate.cvHarmonicTemplate('polarPhi', 0.1, polarAngles[1])
                 )
-                colvarsConfig.write(
-                    self.cTemplate.cvProteinTemplate(center, './complex_largeBox.xyz')
-                )
+                if pinDownPro:
+                    colvarsConfig.write(
+                        self.cTemplate.cvProteinTemplate(center, './complex_largeBox.xyz')
+                    )
 
         # 008_RMSDUnbound
         for i in range(stratification[7]):
@@ -1871,11 +1957,16 @@ class inputGenerator():
                     )
                 )
 
-    def _duplicateFileFolder(self,path, number):
-        ''' duplicate the ./BFEE folder
-            Inputs:
-                path (string): the directory for generation of all the files
-                number (int): the number of copies '''
+    def _duplicateFileFolder(self, path, number):
+        """duplicate the ./BFEE folder
+
+        Args:
+            path (string): the directory for generation of all the files
+            number (int): the number of copies
+
+        Raises:
+            DirectoryExistError: if {path}/BFEE_{i} exists
+        """        
         for i in range(number - 1):
             if os.path.exists(f'{path}/BFEE_{i}'):
                 raise DirectoryExistError('Directory exists')
